<?php
/**
 * Theme Functions.
 */

/* Theme Setup */
if ( ! function_exists( 'perfect_blogging_setup' ) ) :
	function perfect_blogging_setup() {
		
		$GLOBALS['content_width'] = apply_filters( 'perfect_blogging_content_width', 640 );

		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'align-wide' );
		add_theme_support( 'wp-block-styles' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );

		add_theme_support( 'custom-background', array(
			'default-color' => 'f1f1f1'
		) );

		add_theme_support( 'html5', array(
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
		) );

		add_theme_support('responsive-embeds');

		add_editor_style( array( 'css/editor-style.css', perfect_blog_font_url() ) );
	}
endif;
add_action( 'after_setup_theme', 'perfect_blogging_setup' );

/* Theme Widgets Setup */
function perfect_blogging_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Blog Sidebar', 'perfect-blogging' ),
		'description'   => __( 'Appears on blog page sidebar', 'perfect-blogging' ),
		'id'            => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Page Sidebar', 'perfect-blogging' ),
		'description'   => __( 'Appears on page sidebar', 'perfect-blogging' ),
		'id'            => 'sidebar-2',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Third Column Sidebar', 'perfect-blogging' ),
		'description'   => __( 'Appears on page sidebar', 'perfect-blogging' ),
		'id'            => 'sidebar-3',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Home Page Sidebar', 'perfect-blogging' ),
		'description'   => __( 'Appears on Home Page', 'perfect-blogging' ),
		'id'            => 'home-page',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	//Footer widget areas
	$perfect_blog_widget_areas = get_theme_mod('perfect_blog_footer_widget_areas', '4');
	for ($i=1; $i<=$perfect_blog_widget_areas; $i++) {
		register_sidebar( array(
			'name'          => __( 'Footer Nav ', 'perfect-blogging' ) . $i,
			'id'            => 'footer-' . $i,
			'description'   => '',
			'before_widget' => '<aside id="%1$s" class="widget %2$s">',
			'after_widget'  => '</aside>',
			'before_title'  => '<h3 class="widget-title">',
			'after_title'   => '</h3>',
		) );
	}

	register_sidebar( array(
		'name'          => __( 'Shop Page Sidebar', 'perfect-blogging' ),
		'description'   => __( 'Appears on shop page', 'perfect-blogging' ),
		'id'            => 'woocommerce_sidebar',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => __( 'Single Product Page Sidebar', 'perfect-blogging' ),
		'description'   => __( 'Appears on shop page', 'perfect-blogging' ),
		'id'            => 'woocommerce-single-sidebar',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}

add_action( 'widgets_init', 'perfect_blogging_widgets_init' );

add_action( 'wp_enqueue_scripts', 'perfect_blogging_enqueue_styles' );
function perfect_blogging_enqueue_styles() {
	$parent_style = 'perfect-blog-basic-style'; // Style handle of parent theme.
	wp_enqueue_style( $parent_style, esc_url(get_template_directory_uri()) . '/style.css' );
	wp_enqueue_style( 'perfect-blogging-basic-style', get_stylesheet_uri(), array( $parent_style ) );
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
	wp_enqueue_style( 'perfect-blogging-block-patterns-style-frontend', get_theme_file_uri('/theme-block-pattern/css/block-pattern-frontend.css') );

	$perfect_blog_custom_css = '';

	$perfect_blog_show_header = get_theme_mod( 'perfect_blogging_button_border', false);
	if($perfect_blog_show_header == true){
		$perfect_blog_custom_css .='.read-comp a,#slider .inner_carousel .more-btn a{';
			$perfect_blog_custom_css .='border:2px solid; margin:10px 0;';
		$perfect_blog_custom_css .='}';
	}

	$perfect_blog_button_padding_top_bottom = get_theme_mod('perfect_blog_button_padding_top_bottom');
	$perfect_blog_button_padding_left_right = get_theme_mod('perfect_blog_button_padding_left_right');
	$perfect_blog_custom_css .='.read-comp a,#slider .inner_carousel .more-btn a{';
		$perfect_blog_custom_css .='padding-top: '.esc_attr($perfect_blog_button_padding_top_bottom).'px; padding-bottom: '.esc_attr($perfect_blog_button_padding_top_bottom).'px; padding-left: '.esc_attr($perfect_blog_button_padding_left_right).'px; padding-right: '.esc_attr($perfect_blog_button_padding_left_right).'px; display:inline-block;';
	$perfect_blog_custom_css .='}';

	$perfect_blog_button_border_radius = get_theme_mod('perfect_blog_button_border_radius');
	$perfect_blog_custom_css .='.read-comp a,#slider .inner_carousel .more-btn a, #comments .form-submit input[type="submit"]{';
		$perfect_blog_custom_css .='border-radius: '.esc_attr($perfect_blog_button_border_radius).'px;';
	$perfect_blog_custom_css .='}';

	// site title and tagline font size option
	$perfect_blog_site_title_size_option = get_theme_mod('perfect_blog_site_title_size_option', 35);{
		$perfect_blog_custom_css .='#header .logo a{';
		$perfect_blog_custom_css .='font-size: '.esc_attr($perfect_blog_site_title_size_option).'px;';
		$perfect_blog_custom_css .='}';
	}

	$perfect_blog_site_tagline_size_option = get_theme_mod('perfect_blog_site_tagline_size_option', 13);{
		$perfect_blog_custom_css .='#header .logo p{';
		$perfect_blog_custom_css .='font-size: '.esc_attr($perfect_blog_site_tagline_size_option).'px;';
		$perfect_blog_custom_css .='}';
	}

	wp_add_inline_style( 'perfect-blogging-basic-style',$perfect_blog_custom_css );
}

function perfect_blogging_customize_register() {     
		global $wp_customize;
		$wp_customize->remove_section( 'perfect_blog_theme_color_option' );  //Modify this line as needed  
	} 
add_action( 'customize_register', 'perfect_blogging_customize_register', 11 );

// Customizer Section
function perfect_blogging_customizer ( $wp_customize ) {

	$wp_customize->add_section( 'perfect_blogging_category_post_section' , array(
    	'title'      => __( 'Single Category Post', 'perfect-blogging' ),
		'priority'   => null,
		'panel' => 'perfect_blog_panel_id'
	) );

	$categories = get_categories();
	$cats = array();
	$i = 0;
	$cat_post[]= 'select';
	foreach($categories as $category){
		if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_post[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('perfect_blogging_category_post',array(
		'default'	=> 'select',
		'sanitize_callback' => 'perfect_blogging_sanitize_choices',
	));
	$wp_customize->add_control('perfect_blogging_category_post',array(
		'type'    => 'select',
		'choices' => $cat_post,
		'label' => __('Select Category to display post','perfect-blogging'),
		'section' => 'perfect_blogging_category_post_section',
	));

    // Single Category Post
    $wp_customize->add_setting( 'perfect_blogging_category_button_text', array(
		'default'   => __('Read Complete Post','perfect-blogging' ),
		'sanitize_callback'	=> 'sanitize_text_field'
	) );
	$wp_customize->add_control( 'perfect_blogging_category_button_text', array(
		'label'    => __( 'Category Post Button text','perfect-blogging' ),
		'section'  => 'perfect_blogging_category_post_section',
		'type'     => 'text',
		'settings' => 'perfect_blogging_category_button_text'
	) );
	
	//Show /Hide border
	$wp_customize->add_setting( 'perfect_blogging_button_border',array(
		'default' => '',
      	'sanitize_callback'	=> 'perfect_blog_sanitize_checkbox'
    ) );
    $wp_customize->add_control('perfect_blogging_button_border',array(
    	'type' => 'checkbox',
        'label' => __( 'Show / Hide Button Border','perfect-blogging' ),
        'section' => 'perfect_blog_theme_button'
    ));

}
add_action( 'customize_register', 'perfect_blogging_customizer' );

/**
	 * Enqueue block editor style
	 */
	function perfect_blogging_block_editor_styles() {
		wp_enqueue_style( 'perfect_blogging-font', perfect_blog_font_url(), array() );
	    wp_enqueue_style( 'perfect_blogging-block-patterns-style-editor', get_theme_file_uri( '/theme-block-pattern/css/block-pattern-editor.css' ), false, '1.0', 'all' );
	    wp_enqueue_style('font-awesome-style', esc_url(get_template_directory_uri()).'/css/fontawesome-all.css');
	}
	add_action( 'enqueue_block_editor_assets', 'perfect_blogging_block_editor_styles' );


/*radio button sanitization*/
function perfect_blogging_sanitize_choices( $input, $setting ) {
    global $wp_customize; 
    $control = $wp_customize->get_control( $setting->id ); 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

/* Block Pattern */
require get_theme_file_path('/theme-block-pattern/theme-block-pattern.php');